==> knt_bloc-3.2.1.tar.gz: lib/src/bloc/states.dart <==
part of 'blocs.dart';

abstract class BaseState {
  const BaseState({String? tag}) : this._tag = tag;

  /// Defined ID for this state, will be used for handle event & state
  final String? _tag;

  String get tag => _tag ?? runtimeType.toString();
}

class BaseInitState extends BaseState {
  const BaseInitState({super.tag});
}

class BaseResetDoneState extends BaseState {
  const BaseResetDoneState({super.tag});
}

class BaseLoadingState extends BaseState {
  const BaseLoadingState({super.tag});
}

class BaseErrorState extends BaseState {
  const BaseErrorState({
    required this.exception,
    super.tag,
  });

  final KntException exception;

  @override
  String toString() => '$runtimeType { tag: $tag, exception: $exception }';
}

class BaseEmptyResultState extends BaseState {
  const BaseEmptyResultState({super.tag});
}

class BaseHasResultState<D> extends BaseState {
  const BaseHasResultState(
    this.data, {
    super.tag,
  });

  final D data;

  @override
  String toString() => '$runtimeType { tag: $tag, data: ${data?.toString()} }';
}

class BasePagingResultState<D> extends BaseHasResultState<List<D>> {
  const BasePagingResultState(
    List<D> dataList,
    this.currentOffset, {
    super.tag,
  }) : super(dataList);

  final int currentOffset;
}

class ChangedPagingDataState<D> extends BaseState {
  const ChangedPagingDataState({
    required this.action,
    required this.data,
    required this.newPosition,
    this.focusToNewPosition = true,
    super.tag,
  });

  final PagingDataAction action;

  /// In case [PagingDataAction.create] or [PagingDataAction.edit] it will be the latest data.
  /// In case [PagingDataAction.delete] it was the old data before deleting.
  final D data;

  /// Position which we should focus on after doing [action]
  final int newPosition;

  /// Whether we should focus (jump to / animate to) on [newPosition]
  final bool focusToNewPosition;
}

enum PagingDataAction { create, edit, delete }

==> knt_bloc-4.0.0.tar.gz: lib/src/bloc/states.dart <==
part of 'blocs.dart';

abstract class BaseState {
  const BaseState({String? tag}) : _tag = tag;

  /// Defined ID for this state, will be used for handle event & state.
  final String? _tag;

  String get tag => _tag ?? runtimeType.toString();
}

class BaseInitState extends BaseState {
  const BaseInitState({super.tag});
}

class BaseResetDoneState extends BaseState {
  const BaseResetDoneState({super.tag});
}

class BaseLoadingState extends BaseState {
  const BaseLoadingState({super.tag});
}

class BaseErrorState extends BaseState {
  const BaseErrorState({
    required this.exception,
    super.tag,
  });

  final KntException exception;

  @override
  String toString() => '{ tag: $tag, exception: $exception }';
}

class BaseEmptyResultState extends BaseState {
  const BaseEmptyResultState({super.tag});
}

class BaseHasResultState<D> extends BaseState {
  const BaseHasResultState(
    this.data, {
    super.tag,
  });

  final D data;

  @override
  String toString() => '{ tag: $tag, data: $data }';
}

class BasePagingResultState<D> extends BaseHasResultState<List<D>> {
  const BasePagingResultState(
    super.dataList,
    this.currentOffset, {
    super.tag,
  });

  final int currentOffset;
}

class ChangedPagingDataState<D> extends BaseState {
  const ChangedPagingDataState({
    required this.action,
    required this.data,
    required this.newPosition,
    this.focusToNewPosition = true,
    super.tag,
  });

  final PagingDataAction action;

  /// In case [PagingDataAction.create] or [PagingDataAction.edit] it will be
  /// the latest data.
  /// In case [PagingDataAction.delete] it was the old data before deleting.
  final D data;

  /// Position which we should focus on after doing [action].
  final int newPosition;

  /// Whether we should focus (jump to / animate to) on [newPosition].
  final bool focusToNewPosition;
}

enum PagingDataAction { create, edit, delete }
